@@ -9,9 +9,9 @@ use parent 'TableData::Munge::GroupRows';
 use DateTime;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-26'; # DATE
+our $DATE = '2023-12-28'; # DATE
 our $DIST = 'TableDataBundle-Perl-CPAN-Release'; # DIST
-our $VERSION = '20231126.0'; # VERSION
+our $VERSION = '20231228.0'; # VERSION
 
 my $re_period = qr/\A(\d\d\d\d)-(\d\d)/;
 
@@ -43,7 +43,7 @@ sub new {
     );
 }
 
-# STATS
+our %STATS = ("num_rows",341,"num_columns",2); # STATS
 
 1;
 # ABSTRACT: CPAN releases (grouped monthly)
@@ -60,7 +60,7 @@ TableData::Perl::CPAN::Release::Static::GroupedMonthly - CPAN releases (grouped
 
 =head1 VERSION
 
-This document describes version 20231126.0 of TableData::Perl::CPAN::Release::Static::GroupedMonthly (from Perl distribution TableDataBundle-Perl-CPAN-Release), released on 2023-11-26.
+This document describes version 20231228.0 of TableData::Perl::CPAN::Release::Static::GroupedMonthly (from Perl distribution TableDataBundle-Perl-CPAN-Release), released on 2023-12-28.
 
 =head1 SYNOPSIS
 
@@ -98,7 +98,7 @@ See the L<tabledata> CLI's documentation for other available actions and options
  | key         | value |
  +-------------+-------+
  | num_columns | 2     |
- | num_rows    | 340   |
+ | num_rows    | 341   |
  +-------------+-------+
 
 The statistics is available in the C<%STATS> package variable.
