@@ -9,9 +9,9 @@ use parent 'TableData::Munge::GroupRows';
 use DateTime;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-26'; # DATE
+our $DATE = '2023-12-28'; # DATE
 our $DIST = 'TableDataBundle-Perl-CPAN-Release'; # DIST
-our $VERSION = '20231126.0'; # VERSION
+our $VERSION = '20231228.0'; # VERSION
 
 my $re_date = qr/\A(\d\d\d\d)-(\d\d)-(\d\d)/;
 
@@ -47,7 +47,7 @@ sub new {
     );
 }
 
-# STATS
+our %STATS = ("num_columns",2,"num_rows",1479); # STATS
 
 1;
 # ABSTRACT: CPAN releases (grouped weekly)
@@ -64,7 +64,7 @@ TableData::Perl::CPAN::Release::Static::GroupedWeekly - CPAN releases (grouped w
 
 =head1 VERSION
 
-This document describes version 20231126.0 of TableData::Perl::CPAN::Release::Static::GroupedWeekly (from Perl distribution TableDataBundle-Perl-CPAN-Release), released on 2023-11-26.
+This document describes version 20231228.0 of TableData::Perl::CPAN::Release::Static::GroupedWeekly (from Perl distribution TableDataBundle-Perl-CPAN-Release), released on 2023-12-28.
 
 =head1 SYNOPSIS
 
@@ -102,7 +102,7 @@ See the L<tabledata> CLI's documentation for other available actions and options
  | key         | value |
  +-------------+-------+
  | num_columns | 2     |
- | num_rows    | 1476  |
+ | num_rows    | 1479  |
  +-------------+-------+
 
 The statistics is available in the C<%STATS> package variable.
